package com.chelvc.framework.base.context;

import com.chelvc.framework.common.model.Enumerable;
import com.chelvc.framework.common.util.DateUtils;
import lombok.Getter;

/**
 * 使用类别枚举
 *
 * @author Woody
 * @date 2023/9/10
 */
@Getter
public enum Using implements Enumerable {
    /**
     * 历史首次
     */
    INITIAL("历史首次"),

    /**
     * 当日首次
     */
    DAILY("当日首次"),

    /**
     * 当前首次
     */
    NEWLY("当前首次"),

    /**
     * 普通请求
     */
    NORMAL("普通请求");

    /**
     * 类别描述
     */
    private final String description;

    Using(String description) {
        this.description = description;
    }

    /**
     * 根据上次使用时间及注册时间结算使用类型
     * <p>
     * 如果距离上次使用时间超过15分钟我（900000毫秒）则视为重新进入系统
     *
     * @param latest      上次使用时间戳
     * @param registering 用户注册时间戳
     * @return 使用类型枚举
     */
    public static Using from(Long latest, Long registering) {
        if (latest == null) {
            return registering == null || registering < DateUtils.today().getTime() ? DAILY : INITIAL;
        }
        return System.currentTimeMillis() - latest > 900000 ? NEWLY : NORMAL;
    }
}
